@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -340,7 +340,7 @@ function cdef_item_remove_confirm() {
 	<tr>
 		<td class='topBoxAlt'>
 			<p><?php print __('Click \'Continue\' to delete the following CDEF Item.');?></p>
-			<p><?php print __('CDEF Name: %s', html_escape($cdef['name']));?><br>
+			<p><?php print __esc('CDEF Name: %s', $cdef['name']);?><br>
 			<em><?php $cdef_item_type = $cdef_item['type']; print $cdef_item_types[$cdef_item_type];?></em>: <strong><?php print html_escape(get_cdef_item_name($cdef_item['id']));?></strong></p>
 		</td>
 	</tr>
@@ -446,7 +446,7 @@ function item_edit() {
 		WHERE id = ?',
 		array(get_request_var('cdef_id')));
 
-	html_start_box(__('CDEF Items [edit: %s]', html_escape($cdef_name)), '100%', '', '3', 'center', '');
+	html_start_box(__esc('CDEF Items [edit: %s]', $cdef_name), '100%', '', '3', 'center', '');
 
 	if (isset_request_var('type_select')) {
 		$current_type = get_request_var('type_select');
@@ -583,7 +583,7 @@ function cdef_edit() {
 
 	if (!isempty_request_var('id')) {
 		$cdef = db_fetch_row_prepared('SELECT * FROM cdef WHERE id = ?', array(get_request_var('id')));
-		$header_label = __('CDEF [edit: %s]', html_escape($cdef['name']));
+		$header_label = __esc('CDEF [edit: %s]', $cdef['name']);
 	} else {
 		$header_label = __('CDEF [new]');
 	}
