@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -55,7 +55,7 @@ if (!function_exists('get_cacti_cli_version')) {
 
 if (!function_exists('is_resource_writable')) {
 	function is_resource_writable($path) {
-		if ($path{strlen($path)-1}=='/') {
+		if ($path[strlen($path)-1]=='/') {
 			return is_resource_writable($path.uniqid(mt_rand()).'.tmp');
 		}
 
@@ -966,7 +966,7 @@ function loadTable($db, &$records) {
 
 function display_version() {
 	if (!defined('COPYRIGHT_YEARS')) {
-		define('COPYRIGHT_YEARS', '2004-2019');
+		define('COPYRIGHT_YEARS', '2004-2020');
 	}
 
 	$version = get_cacti_cli_version();
