@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -343,7 +343,7 @@ function color_import_processor(&$colors) {
 }
 
 function color_import() {
-	print "<form method='post' action='color.php?action=import' enctype='multipart/form-data'>\n";
+	form_start('color.php?action=import', '', true);
 
 	if ((isset($_SESSION['import_debug_info'])) && (is_array($_SESSION['import_debug_info']))) {
 		html_start_box('Import Results', '100%', '', '3', 'center', '');
@@ -414,7 +414,7 @@ function color_edit() {
 
 	if (!isempty_request_var('id')) {
 		$color = db_fetch_row_prepared('SELECT * FROM colors WHERE id = ?', array(get_request_var('id')));
-		$header_label = __('Colors [edit: %s]', html_escape($color['hex']));
+		$header_label = __esc('Colors [edit: %s]', $color['hex']);
 	} else {
 		$header_label = __('Colors [new]');
 	}
@@ -751,8 +751,8 @@ function color_export() {
 
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
-		$sql_where = "WHERE (name LIKE '%" . get_request_var('filter') . "%'
-			OR hex LIKE '%" .  get_request_var('filter') . "%')";
+		$sql_where = 'WHERE (name LIKE ' . db_qstr('%' . get_request_var('filter') . '%') . '
+			OR hex LIKE ' . db_qstr('%' .  get_request_var('filter') . '%') . ')';
 	} else {
 		$sql_where = '';
 	}
