@@ -208,7 +208,7 @@ if (isset($xport_array['data']) && is_array($xport_array['data'])) {
 
 		// Full UTF-8 Output
 		print "\xEF\xBB\xBF";
-		print mb_convert_encoding($output, 'UTF-16LE', 'UTF-8');
+		print $output;
 	} else {
 		$j = 1;
 		foreach($xport_array['data'] as $row) {
