@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -184,7 +184,6 @@ function host_new_graphs_save($host_id) {
 
 	/* form an array that contains all of the data on the previous form */
 	foreach ($_POST as $var => $val) {
-
 		if (preg_match('/^g_(\d+)_(\d+)_(\w+)/', $var, $matches)) { // 1: snmp_query_id, 2: graph_template_id, 3: field_name
 			if (empty($matches[1])) { // this is a new graph from template field
 				$values['cg'][$matches[2]]['graph_template'][$matches[3]] = $val;
@@ -296,7 +295,7 @@ function graphs() {
 				WHERE id = ?',
 				array($host['host_template_id']));
 
-			$header =  __('New Graphs for [ %s ] (%s %s)', html_escape($host['description']), html_escape($host['hostname']), (!empty($host['host_template_id']) ? html_escape($name):''));
+			$header =  __esc('New Graphs for [ %s ] (%s %s)', $host['description'], $host['hostname'], (!empty($host['host_template_id']) ? $name:''));
 		} else {
 			$header =  __('New Graphs for [ All Devices ]');
 			$host['id'] = -1;
@@ -389,7 +388,7 @@ function graphs() {
 
 								if (cacti_sizeof($snmp_queries) > 0) {
 									foreach ($snmp_queries as $query) {
-										print "<option value='" . $query['id'] . "'"; if (get_request_var('graph_type') == $query['id']) { print ' selected'; } print '>' . $query['name'] . "</option>\n";
+										print "<option value='" . $query['id'] . "'"; if (get_request_var('graph_type') == $query['id']) { print ' selected'; } print '>' . html_escape($query['name']) . '</option>';
 									}
 								}
 								?>
@@ -447,7 +446,10 @@ function graphs() {
 
 	form_start('graphs_new.php', 'chk');
 
-	$total_rows = cacti_sizeof(db_fetch_assoc_prepared('SELECT graph_template_id FROM host_graph WHERE host_id = ?', array(get_request_var('host_id'))));
+	$total_rows = cacti_sizeof(db_fetch_assoc_prepared('SELECT graph_template_id
+		FROM host_graph
+		WHERE host_id = ?',
+		array(get_request_var('host_id'))));
 
 	$i = 0;
 
@@ -649,7 +651,7 @@ function graphs() {
 					}
 				}
 
-				print "<div class='cactiTable'><div><div class='cactiTableTitle'><span>" . __('Data Query [%s]', $snmp_query['name']) . "</span></div><div class='cactiTableButton'><span class='reloadquery fa fa-sync' id='reload" . $snmp_query['id'] . "' data-id='" . $snmp_query['id'] . "'></span></div></div></div>\n";
+				print "<div class='cactiTable'><div><div class='cactiTableTitle'><span>" . __esc('Data Query [%s]', $snmp_query['name']) . "</span></div><div class='cactiTableButton'><span class='reloadquery fa fa-sync' id='reload" . $snmp_query['id'] . "' data-id='" . $snmp_query['id'] . "'></span></div></div></div>\n";
 
 				if ($xml_array != false) {
 					$html_dq_header = '';
