@@ -151,6 +151,8 @@ if (read_config_option('auth_method') != 0) {
 
 		if (!isset($guest_account) && $guest_user_id == $_SESSION['sess_user_id']) {
 			kill_session_var('sess_user_id');
+			cacti_session_destroy();
+			cacti_session_start();
 		}
 	}
 
@@ -263,6 +265,10 @@ if (read_config_option('auth_method') != 0) {
 				) AS authorized';
 
 			$authorized = db_fetch_cell_prepared($auth_sql_query, $auth_sql_params);
+
+			if (!$authorized) {
+				auth_login_redirect();
+			}
 		} else {
 			$authorized = false;
 		}
