@@ -174,7 +174,6 @@ $no_http_header_files = array(
 	'query_host_cpu.php',
 	'query_host_partitions.php',
 	'rebuild_poller_cache.php',
-	'remote_agent.php',
 	'repair_database.php',
 	'script_server.php',
 	'snmpagent_mibcachechild.php',
@@ -424,16 +423,12 @@ if ($config['is_web']) {
 	header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
 	header('X-Frame-Options: SAMEORIGIN');
 
-	// SameSite legacy behavior
-	if (version_compare(PHP_VERSION, '7.3', '<')) {
-		header('Set-Cookie: cross-site-cookie=bar; SameSite=Strict;' . (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off' ? ' Secure':''));
-	}
-
 	/* increased web hardening */
 	$script_policy = read_config_option('content_security_policy_script');
 	if ($script_policy != '0' && $script_policy != '') {
 		$script_policy = "'$script_policy'";
 	}
+
 	header("Content-Security-Policy: default-src *; img-src 'self' data: blob:; style-src 'self' 'unsafe-inline'; script-src 'self' $script_policy 'unsafe-inline'; frame-ancestors 'self'; worker-src 'self'");
 
 	/* prevent IE from silently rejects cookies sent from third party sites. */
