@@ -64,6 +64,8 @@ function imageOptionsChanged(action) {
 				$('#image').html('<img id="rimage" class="realtimeimage" src="data:image/png;base64,'+data.data+'"/>');
 			}
 
+			realtimePopout = $('#rtfilter').outerHeight() + 60 + $('#rimage').outerHeight() + 30 > window.innerHeight || $('#rimage').outerWidth() + 40 > window.innerWidth ? true : false;
+
 			if (realtimePopout) {
 				setRealtimeWindowSize();
 
@@ -265,7 +267,7 @@ function realtimeGrapher() {
 
 		realtimeTimer = setTimeout(function() {
 			realtimeGrapher();
-		}, 1000);
+		}, $('#ds_step').val()*1000);
 	} else {
 		count--;
 		destroy(realtimeTimer);
