@@ -137,7 +137,7 @@ function themeReady() {
 	setImportFile(noFileSelected);
 
 	function setImportFile(fileText) {
-		$('.import_text').html(fileText);
+		$('.import_text').text(fileText);
 	}
 
 	$('select.colordropdown').dropcolor();
