@@ -1080,8 +1080,9 @@ function api_device_ping_device($device_id, $from_remote = false) {
 						$snmp_contact    = cacti_snmp_session_get($session, '.1.3.6.1.2.1.1.4.0');
 
 						print '<strong>' . __('System:') . '</strong> ' . html_split_string($snmp_system) . '<br>';
-						$days      = intval($snmp_uptime / (60*60*24*100));
-						$remainder = $snmp_uptime % (60*60*24*100);
+						$snmp_uptime_ticks = intval($snmp_uptime);
+						$days      = intval($snmp_uptime_ticks / (60*60*24*100));
+						$remainder = $snmp_uptime_ticks % (60*60*24*100);
 						$hours     = intval($remainder / (60*60*100));
 						$remainder = $remainder % (60*60*100);
 						$minutes   = intval($remainder / (60*100));
