@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -55,16 +55,16 @@ function clog_validate_filename(&$file, &$filepath, &$filename, $filecheck = fal
 	global $config;
 
 	$logfile = read_config_option('path_cactilog');
-	$logbase = basename($logfile);
-
 	if ($logfile == '') {
 		$logfile = $config['base_path'] . '/log/cacti.log';
 	}
 
-	$errfile = read_config_option('path_stderrlog');
-	$errbase = basename($errfile);
+	$errfile  = read_config_option('path_stderrlog');
+	$errbase  = basename($errfile);
+
+	$file     = basename($file);
+	$logbase  = basename($logfile);
 
-	$file = basename($file);
 	$filepath = '';
 	$filename = '';
 	$filefull = '';
@@ -783,7 +783,7 @@ function clog_regex_datasource($matches) {
 			if (array_key_exists($ds_id, $ds_titles)) {
 				$ds_title = $ds_titles[$ds_id];
 			}
-			$result .= ($i == 0 ? '':', ') . "<a href='" . html_escape($config['url_path'] . 'data_sources.php?action=ds_edit&id=' . $ds_id) . "'>" . $ds_title . '</a>';
+			$result .= ($i == 0 ? '':', ') . "<a href='" . html_escape($config['url_path'] . 'data_sources.php?action=ds_edit&id=' . $ds_id) . "'>" . html_escape($ds_title) . '</a>';
 
 			$i++;
 		}
