@@ -32,12 +32,21 @@
 function nth_percentile($local_data_ids, $start_seconds, $end_seconds, $percentile = 95, $resolution = 0, $peak = false) {
 	$stats = json_decode(rrdtool_function_stats($local_data_ids, $start_seconds, $end_seconds, $percentile, $resolution, $peak), true);
 
-	$return_val = false;
-	if (!empty($stats)) {
-		if ($peak) {
-			$return_val = $stats['peak'];
+	if ($peak) {
+		if (array_key_exists('peak', $stats)) {
+			return $stats['peak'];
+		} else if (array_key_exists('avg', $stats)) {
+			return $stats['avg'];
 		} else {
-			$return_val = $stats['avg'];
+			return $stats;
+		}
+	} else {
+		if (array_key_exists('avg', $stats)) {
+			return $stats['avg'];
+		} else if (array_key_exists('peak', $stats)) {
+			return $stats['peak'];
+		} else {
+			return $stats;
 		}
 	}
 }
