@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -349,9 +349,17 @@ function draw_edit_control($field_name, &$field_array) {
 
 		break;
 	case 'checkbox_group':
-		print "<div id='${field_name}_group' class='checkboxgroup1'>" . PHP_EOL;
+		if (isset($field_array['type']) && $field_array['type'] == 'flex') {
+			print "</td></tr><tr><td><div id='${field_name}_group' class='checkboxgroup1 flexContainer'>" . PHP_EOL;
+		} else {
+			print "<div id='${field_name}_group' class='checkboxgroup1'>" . PHP_EOL;
+		}
 
 		foreach ($field_array['items'] as $check_name => $check_array) {
+			if (isset($field_array['type']) && $field_array['type'] == 'flex') {
+				print '<div class="flexChild">';
+			}
+
 			form_checkbox(
 				$check_name,
 				$check_array['value'],
@@ -364,10 +372,18 @@ function draw_edit_control($field_name, &$field_array) {
 				true
 			);
 
-			print '<br>';
+			if (isset($field_array['type']) && $field_array['type'] == 'flex') {
+				print '</div>';
+			} else {
+				print '<br>';
+			}
 		}
 
-		print '</div>' . PHP_EOL;
+		if (isset($field_array['type']) && $field_array['type'] == 'flex') {
+			print '</div>' . PHP_EOL;
+		} else {
+			print '</div>' . PHP_EOL;
+		}
 
 		break;
 	case 'radio':
@@ -565,7 +581,7 @@ function form_filepath_box($form_name, $form_previous_value, $form_default_value
 
 	print " class='ui-state-default ui-corner-all$error_class'";
 
-	print " id='$form_name' placeholder='" . __('Enter a valid file path') . "' name='$form_name' size='$form_size'" . (!empty($form_max_length) ? " maxlength='$form_max_length'" : '') . " value='" . html_escape($form_previous_value) . "'>" . $extra_data;
+	print " id='$form_name' placeholder='" . __esc('Enter a valid file path') . "' name='$form_name' size='$form_size'" . (!empty($form_max_length) ? " maxlength='$form_max_length'" : '') . " value='" . html_escape($form_previous_value) . "'>" . $extra_data;
 }
 
 /* form_dirpath_box - draws a standard html textbox and provides status of a directories existence
@@ -612,7 +628,7 @@ function form_dirpath_box($form_name, $form_previous_value, $form_default_value,
 		$extra_data = "<span class='cactiTooltipHint fa fa-times-circle' style='padding:5px;font-size:16px;color:red' title='" . __esc('Directory is Not found'). "'></span>";
 	}
 
-	print " id='$form_name' name='$form_name' placeholder='" . __('Enter a valid directory path'). "' size='$form_size'" . (!empty($form_max_length) ? " maxlength='$form_max_length'" : '') . " value='" . html_escape($form_previous_value) . "'>" . $extra_data;
+	print " id='$form_name' name='$form_name' placeholder='" . __esc('Enter a valid directory path'). "' size='$form_size'" . (!empty($form_max_length) ? " maxlength='$form_max_length'" : '') . " value='" . html_escape($form_previous_value) . "'>" . $extra_data;
 }
 
 /* form_text_box - draws a standard html textbox
@@ -636,10 +652,10 @@ function form_text_box($form_name, $form_previous_value, $form_default_value, $f
 	}
 
 	if ($type == 'password') {
-		print "<input type='text' style='display:none' value=''><input type='password' style='display:none' autocomplete='new-password' value=''>";
+		print "<input type='text' style='display:none' value=''><input type='password' style='display:none' autocomplete='current-password' value=''>";
 	}
 
-	print "<input type='$type' " . ($type == 'password' || $type == 'password_confirm' ? 'autocomplete="new-password"':'off') . ($title != '' ? ' title="' . $title . '"':'');
+	print "<input type='$type' " . ($type == 'password' || $type == 'password_confirm' ? 'autocomplete="current-password"':'off') . ($title != '' ? ' title="' . $title . '"':'');
 
 	if (isset($_SESSION['sess_error_fields'])) {
 		if (!empty($_SESSION['sess_error_fields'][$form_name])) {
@@ -648,6 +664,8 @@ function form_text_box($form_name, $form_previous_value, $form_default_value, $f
 		} else {
 			print " class='ui-state-default ui-corner-all'";
 		}
+	} else {
+		print " class='ui-state-default ui-corner-all'";
 	}
 
 	if (isset($_SESSION['sess_field_values']) && isset($_SESSION['sess_error_fields'])) {
@@ -656,7 +674,7 @@ function form_text_box($form_name, $form_previous_value, $form_default_value, $f
 		}
 	}
 
-	print " id='$form_name' " . ($placeholder != '' ? "placeholder='$placeholder'":'') . " name='$form_name' size='$form_size'" . (!empty($form_max_length) ? " maxlength='$form_max_length'" : '') . " value='" . html_escape($form_previous_value) . "'>\n";
+	print " id='$form_name' " . ($placeholder != '' ? "placeholder='" . html_escape($placeholder) . "'":'') . " name='$form_name' size='$form_size'" . (!empty($form_max_length) ? " maxlength='$form_max_length'" : '') . " value='" . html_escape($form_previous_value) . "'>\n";
 }
 
 /* form_hidden_box - draws a standard html hidden element
@@ -1028,7 +1046,7 @@ function form_text_area($form_name, $form_previous_value, $form_rows, $form_colu
 	}
 
 	if ($placeholder != '') {
-		$placeholder = " placeholder='$placeholder'";
+		$placeholder = " placeholder='" . html_escape($placeholder) . "'";
 	}
 
 	print "<textarea class='$class ui-state-default ui-corner-all' aria-multiline='true' cols='$form_columns' rows='$form_rows' id='$form_name' name='$form_name'" . $on_change . $placeholder . '>' . html_escape($form_previous_value) . "</textarea>\n";
@@ -1159,11 +1177,11 @@ function form_color_dropdown($form_name, $form_previous_value, $form_none_entry,
 				print ' selected';
 			}
 
-			print '>' . $display . "</option>";
+			print '>' . html_escape($display) . '</option>';
 		}
 	}
 
-	print "</select>";
+	print '</select>';
 }
 
 /* form_font_box - draws a standard html textbox and provides status of a fonts existence
