@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -178,7 +178,7 @@ function html_graph_preview_filter($page, $action, $devices_where = '', $templat
 											}
 										}
 										print '>';
-										print $gt['name'] . "</option>\n";
+										print html_escape($gt['name']) . "</option>\n";
 									}
 								}
 							}
