@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -184,31 +184,33 @@ function grow_dhtml_trees() {
 				return $(this).width();
 			}).get());
 
-			var minWidth = <?php print read_user_setting('min_tree_width');?>;
-			var maxWidth = <?php print read_user_setting('max_tree_width');?>;
-
 			if (visWidth < 0) {
-				$('.cactiTreeNavigationArea').width(0);
+				$('.cactiTreeNavigationArea').css('width', 0);
 				$('.cactiGraphContentArea').css('margin-left', 0);
 				$('.cactiTreeNavigationArea').css('overflow-x', '');
-			} else if (visWidth < minWidth) {
-				$('.cactiTreeNavigationArea').width(minWidth);
-				$('.cactiGraphContentArea').css('margin-left', minWidth+5);
+			} else if (visWidth < minTreeWidth) {
+				$('.cactiTreeNavigationArea').css('width', minTreeWidth);
+				$('.cactiGraphContentArea').css('margin-left', minTreeWidth+5);
 				$('.cactiTreeNavigationArea').css('overflow-x', '');
-			} else if (visWidth > maxWidth) {
-				$('.cactiTreeNavigationArea').width(maxWidth);
-				$('.cactiGraphContentArea').css('margin-left', maxWidth+5);
+			} else if (visWidth > maxTreeWidth) {
+				$('.cactiTreeNavigationArea').css('width', maxTreeWidth);
+				$('.cactiGraphContentArea').css('margin-left', maxTreeWidth+5);
 				$('.cactiTreeNavigationArea').css('overflow-x', 'auto');
 			} else if (visWidth > navWidth) {
-				$('.cactiTreeNavigationArea').width(visWidth);
+				$('.cactiTreeNavigationArea').css('width', visWidth);
 				$('.cactiGraphContentArea').css('margin-left', visWidth+5);
 				$('.cactiTreeNavigationArea').css('overflow-x', 'auto');
 			} else {
-				$('.cactiTreeNavigationArea').width(navWidth);
+				$('.cactiTreeNavigationArea').css('width', navWidth);
 				$('.cactiGraphContentArea').css('margin-left', navWidth+5);
 				$('.cactiTreeNavigationArea').css('overflow-x', '');
 			}
 		}
+
+		var navWidth = $('#navigation').width();
+		if (navWidth > 0) {
+			$('#searcher').css('width', navWidth-70);
+		}
 	}
 
 	function checkTreeForLogout() {
@@ -256,9 +258,11 @@ function grow_dhtml_trees() {
 				if (nodes.length > 0) {
 					$('#jstree').jstree().clear_state();
 				}
+				resizeTreePanel();
 			})
 			.on('loaded.jstree', function() {
 				openNodes();
+				resizeTreePanel();
 			})
 			.on('ready.jstree', function() {
 				resizeTreePanel();
@@ -712,10 +716,18 @@ function create_data_query_branch($leaf, $site_id = -1, $ht = -1) {
 	if (cacti_sizeof($data_queries)) {
 		if ($leaf['host_id'] > 0) {
 			$ntg = get_allowed_graphs('gl.host_id=' . $leaf['host_id'] . ' AND gl.snmp_query_id=0');
-			$agg = get_allowed_aggregate_graphs('gl.host_id=' . $leaf['host_id'] . ' AND gl.snmp_query_id=0');
+			if (read_user_setting('show_aggregates', 'on') == 'on') {
+				$agg = get_allowed_aggregate_graphs('gl.host_id=' . $leaf['host_id'] . ' AND gl.snmp_query_id=0');
+			} else {
+				$agg = array();
+			}
 		} else {
 			$ntg = get_allowed_graphs('gl.snmp_query_id=0');
-			$agg = get_allowed_aggregate_graphs('gl.snmp_query_id=0');
+			if (read_user_setting('show_aggregates', 'on') == 'on') {
+				$agg = get_allowed_aggregate_graphs('gl.snmp_query_id=0');
+			} else {
+				$agg = array();
+			}
 		}
 
 		$ntg = array_merge($ntg, $agg);
@@ -1004,7 +1016,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 	?>
 	<tr class='even noprint' id='search'>
 		<td class='noprint'>
-		<form name='form_graph_view' method='post' onSubmit='applyGraphFilter();return false'>
+		<form id='form_graph_view' method='post' onSubmit='applyGraphFilter();return false'>
 			<table class='filterTable'>
 				<tr>
 					<td>
@@ -1041,8 +1053,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 												print ' selected';
 											}
 										}
-										print '>';
-										print $gt['name'] . "</option>\n";
+										print '>' . html_escape($gt['name']) . '</option>';
 									}
 								}
 							}
@@ -1358,7 +1369,11 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 		}
 
 		$graphs = get_allowed_graphs($sql_where);
-		$agg    = get_allowed_aggregate_graphs($sql_where);
+		if (read_user_setting('show_aggregates', 'on') == 'on') {
+			$agg = get_allowed_aggregate_graphs($sql_where);
+		} else {
+			$agg = array();
+		}
 
 		$graphs = array_merge($graphs, $agg);
 
@@ -1470,12 +1485,20 @@ function get_host_graph_list($host_id, $graph_template_id, $data_query_id, $host
 			}
 
 			$graph_template_ids = [];
+
 			foreach ($final_templates as $graph_template) {
 				array_push($graph_template_ids, $graph_template['id']);
 			}
+
 			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'gl.graph_template_id IN (' . implode(', ', $graph_template_ids) . ')';
 			$graphs = get_allowed_graphs($sql_where);
-			$agg    = get_allowed_aggregate_graphs($sql_where);
+
+			if (read_user_setting('show_aggregates', 'on') == 'on') {
+				$agg = get_allowed_aggregate_graphs($sql_where);
+			} else {
+				$agg = array();
+			}
+
 			$graphs = array_merge($graphs, $agg);
 
 			/* let's sort the graphs naturally */
@@ -1533,7 +1556,13 @@ function get_host_graph_list($host_id, $graph_template_id, $data_query_id, $host
 					' ' . ($data_query_index != '' ? ' AND gl.snmp_index = ' . db_qstr($data_query_index): '');
 
 				$graphs = get_allowed_graphs($sql_where);
-				$agg    = get_allowed_aggregate_graphs($sql_where);
+
+				if (read_user_setting('show_aggregates', 'on') == 'on') {
+					$agg = get_allowed_aggregate_graphs($sql_where);
+				} else {
+					$agg = array();
+				}
+
 				$graphs = array_merge($graphs, $agg);
 
 				/* re-key the results on data query index */
