@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -792,7 +792,7 @@ function api_plugin_disable_hooks_all($plugin) {
 }
 
 function api_plugin_register_realm($plugin, $file, $display, $admin = true) {
-	$files = explode(':', $file);
+	$files = explode(',', $file);
 
 	$i = 0;
 	$sql_where = '(';
@@ -991,7 +991,7 @@ function plugin_load_info_defaults($file, $info, $defaults = array()) {
 	}
 
 	$info_fields = array(
-		'name'         => $dir,
+		'name'         => ucfirst($dir),
 		'requires'     => '',
 		'longname'     => ucfirst($dir),
 		'status'       => file_exists($file) ? 0 : -4,
@@ -1011,7 +1011,7 @@ function plugin_load_info_defaults($file, $info, $defaults = array()) {
 
 	if (strstr($dir, ' ') !== false) {
 		$result['status'] = -3;
-	} elseif ($dir != $result['name']) {
+	} elseif (strtolower($dir) != strtolower($result['name'])) {
 		$result['status'] = -2;
 	} elseif (!isset($result['compat']) || cacti_version_compare(CACTI_VERSION, $result['compat'], '<')) {
 		$result['status'] = -1;
