@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -35,7 +35,7 @@ require_once($config['base_path'] . '/lib/dsdebug.php');
 require_once($config['base_path'] . '/lib/boost.php');
 require_once($config['base_path'] . '/lib/reports.php');
 
-global $poller_db_cnn_id, $remote_db_cnn_id;
+global $poller_db_cnn_id, $remote_db_cnn_id, $logged;
 
 if ($config['poller_id'] > 1 && $config['connection'] == 'online') {
 	$poller_db_cnn_id = $remote_db_cnn_id;
@@ -77,6 +77,7 @@ function sig_handler($signo) {
 $force     = false;
 $debug     = false;
 $mibs      = false;
+$logged    = false;
 
 // set the poller_id
 $poller_id = $config['poller_id'];
@@ -131,6 +132,12 @@ if (cacti_sizeof($parms)) {
 	}
 }
 
+// catch upgrade case
+if (!db_column_exists('poller', 'dbhost')) {
+	cacti_log('Poller is upgrading from pre Cacti 1.0, exiting till upgraded.', false, 'POLLER');
+	exit(0);
+}
+
 $phostname = db_fetch_cell_prepared('SELECT hostname
 	FROM poller
 	WHERE id = ?',
@@ -181,6 +188,12 @@ if (function_exists('pcntl_signal')) {
 $poller_start    = microtime(true);
 $overhead_time   = 0;
 
+// catch the unlikely event that the poller_output_boost is missing
+if (!db_table_exists('poller_output_boost')) {
+	db_execute('CREATE TABLE poller_output_boost LIKE poller_output');
+	db_execute('ALTER TABLE poller_output_boost ENGINE=InnoDB');
+}
+
 api_plugin_hook('poller_top');
 
 // prime the poller_resource_cache for multiple pollers
@@ -359,15 +372,19 @@ while ($poller_runs_completed < $poller_runs) {
 	$loop_start = microtime(true);
 
 	if ($poller_id == '1') {
-		$polling_hosts = array_merge(
-			array(0 => array('id' => '0')),
-			db_fetch_assoc_prepared('SELECT ' . SQL_NO_CACHE . ' id
-				FROM host
-				WHERE poller_id = ?
-				AND disabled=""
-				AND deleted=""
-				ORDER BY id',
-				array($poller_id)));
+		$polling_hosts = db_fetch_assoc_prepared('SELECT ' . SQL_NO_CACHE . ' id
+			FROM host
+			WHERE poller_id = ?
+			AND disabled=""
+			AND deleted=""
+			ORDER BY id',
+			array($poller_id));
+
+		if (cacti_sizeof($polling_hosts)) {
+			$polling_hosts = array_merge(array(0 => array('id' => '0')), $polling_hosts);
+		} else {
+			$polling_hosts = array(0 => array('id' => '0'));
+		}
 	} else {
 		$polling_hosts = db_fetch_assoc_prepared('SELECT ' . SQL_NO_CACHE . ' id
 			FROM host
@@ -378,6 +395,9 @@ while ($poller_runs_completed < $poller_runs) {
 			array($poller_id));
 	}
 
+	$hosts_per_process = 0;
+	$method = 'disabled';
+
 	$script = $server = $snmp = 0;
 
 	$totals = db_fetch_assoc_prepared('SELECT action, count(*) AS totals
@@ -424,6 +444,7 @@ while ($poller_runs_completed < $poller_runs) {
 	$started_processes = 0;
 	$first_host        = 0;
 	$last_host         = 0;
+	$rrds_processed    = 0;
 	$webroot           = addslashes(($config['cacti_server_os'] == 'win32') ? strtr(strtolower(substr(dirname(__FILE__), 0, 1)) . substr(dirname(__FILE__), 1),"\\", '/') : dirname(__FILE__));
 
 	// update web paths for the poller
@@ -572,125 +593,125 @@ while ($poller_runs_completed < $poller_runs) {
 			$extra_parms = '';
 		}
 
-		$extra_args = api_plugin_hook_function('poller_command_args', $extra_args);
-
 		if ($poller_id > 1) {
 			$extra_args .= ' --mode=' . $config['connection'];
 		}
 
 		/* Populate each execution file with appropriate information */
-		foreach ($polling_hosts as $item) {
-			if ($host_count == 1) {
-				$first_host = $item['id'];
-			}
-
-			if ($process_leveling != 'on') {
-				if ($host_count == $hosts_per_process) {
-					$last_host    = $item['id'];
-					$change_proc  = true;
-				}
-			} else {
-				if (isset($items_perhost[$item['id']])) {
-					$items_launched += $items_perhost[$item['id']];
+		if (cacti_sizeof($polling_hosts)) {
+			foreach ($polling_hosts as $item) {
+				if ($host_count == 1) {
+					$first_host = $item['id'];
 				}
 
-				if (($items_launched >= $items_per_process) ||
-					(cacti_sizeof($items_perhost) == $concurrent_processes)) {
-					$last_host      = $item['id'];
-					/* if this is the dummy entry for externally updated data sources
-					 * that are not related to any host (host id = 0), do NOT change_proc */
-					$change_proc    = ($item['id'] == 0 ? false : true);
-					$items_launched = 0;
+				if ($process_leveling != 'on') {
+					if ($host_count == $hosts_per_process) {
+						$last_host    = $item['id'];
+						$change_proc  = true;
+					}
+				} else {
+					if (isset($items_perhost[$item['id']])) {
+						$items_launched += $items_perhost[$item['id']];
+					}
+
+					if (($items_launched >= $items_per_process) ||
+						(cacti_sizeof($items_perhost) == $concurrent_processes)) {
+						$last_host      = $item['id'];
+						/* if this is the dummy entry for externally updated data sources
+						 * that are not related to any host (host id = 0), do NOT change_proc */
+						$change_proc    = ($item['id'] == 0 ? false : true);
+						$items_launched = 0;
+					}
+				}
+
+				$host_count ++;
+
+				if ($change_proc) {
+					exec_background($command_string, "$extra_args --poller=$poller_id --first=$first_host --last=$last_host" . ($mibs ? ' --mibs':''), $extra_parms);
+					usleep(100000);
+
+					$host_count   = 1;
+					$change_proc  = false;
+					$first_host   = 0;
+					$last_host    = 0;
+
+					$started_processes++;
 				}
 			}
 
-			$host_count ++;
+			// launch the last process
+			if ($host_count > 1) {
+				$last_host = $item['id'];
 
-			if ($change_proc) {
 				exec_background($command_string, "$extra_args --poller=$poller_id --first=$first_host --last=$last_host" . ($mibs ? ' --mibs':''), $extra_parms);
 				usleep(100000);
 
-				$host_count   = 1;
-				$change_proc  = false;
-				$first_host   = 0;
-				$last_host    = 0;
-
 				$started_processes++;
 			}
-		}
 
-		// launch the last process
-		if ($host_count > 1) {
-			$last_host = $item['id'];
+			if ($poller_id == 1) {
+				// insert the current date/time for graphs
+				set_config_option('date', date('Y-m-d H:i:s'));
 
-			exec_background($command_string, "$extra_args --poller=$poller_id --first=$first_host --last=$last_host" . ($mibs ? ' --mibs':''), $extra_parms);
-			usleep(100000);
+				// open a pipe to rrdtool for writing
+				$rrdtool_pipe = rrd_init();
+			}
 
-			$started_processes++;
-		}
+			if ($poller_type == '1') {
+				$max_threads = '0';
+			}
 
-		if ($poller_id == 1) {
-			// insert the current date/time for graphs
-			set_config_option('date', date('Y-m-d H:i:s'));
+			$rrds_processed = 0;
+			$poller_finishing_dispatched = false;
+			while (1) {
+				$finished_processes = db_fetch_cell_prepared('SELECT ' . SQL_NO_CACHE . " count(*)
+					FROM poller_time
+					WHERE poller_id = ?
+					AND end_time >'0000-00-00 00:00:00'",
+					array($poller_id), '', true, $poller_db_cnn_id);
 
-			// open a pipe to rrdtool for writing
-			$rrdtool_pipe = rrd_init();
-		}
+				if ($finished_processes >= $started_processes) {
+					// all scheduled pollers are finished
+					if ($poller_finishing_dispatched === false) {
+						api_plugin_hook('poller_finishing');
+						$poller_finishing_dispatched = true;
+					}
 
-		if ($poller_type == '1') {
-			$max_threads = '0';
-		}
+					if ($poller_id == 1) {
+						$rrds_processed = $rrds_processed + process_poller_output($rrdtool_pipe, true);
+					}
 
-		$rrds_processed = 0;
-		$poller_finishing_dispatched = false;
-		while (1) {
-			$finished_processes = db_fetch_cell_prepared('SELECT ' . SQL_NO_CACHE . " count(*)
-				FROM poller_time
-				WHERE poller_id = ?
-				AND end_time >'0000-00-00 00:00:00'",
-				array($poller_id), '', true, $poller_db_cnn_id);
-
-			if ($finished_processes >= $started_processes) {
-				// all scheduled pollers are finished
-				if ($poller_finishing_dispatched === false) {
-					api_plugin_hook('poller_finishing');
-					$poller_finishing_dispatched = true;
-				}
-
-				if ($poller_id == 1) {
-					$rrds_processed = $rrds_processed + process_poller_output($rrdtool_pipe, true);
-				}
-
-				log_cacti_stats($loop_start, $method, $concurrent_processes, $max_threads,
-					($poller_id == '1' ? cacti_sizeof($polling_hosts) - 1 : cacti_sizeof($polling_hosts)), $hosts_per_process, $num_polling_items, $rrds_processed);
-
-				break;
-			} else {
-				if (read_config_option('log_verbosity') >= POLLER_VERBOSITY_MEDIUM || $debug) {
-					print 'Waiting on ' . ($started_processes - $finished_processes) . ' of ' . $started_processes . " pollers.\n";
-				}
-
-				$mtb = microtime(true);
-
-				if ($poller_id == 1) {
-					$rrds_processed = $rrds_processed + process_poller_output($rrdtool_pipe);
-				}
-
-				// end the process if the runtime exceeds MAX_POLLER_RUNTIME
-				if (($poller_start + MAX_POLLER_RUNTIME) < time()) {
-					cacti_log('Maximum runtime of ' . MAX_POLLER_RUNTIME . ' seconds exceeded. Exiting.', true, 'POLLER');
-					admin_email(__('Cacti System Warning'), __('Maximum runtime of %d seconds exceeded for poller id %d. Exiting.', MAX_POLLER_RUNTIME, $poller_id));
-
-					// generate a snmp notification
-					snmpagent_poller_exiting();
-
-					api_plugin_hook_function('poller_exiting');
 					log_cacti_stats($loop_start, $method, $concurrent_processes, $max_threads,
 						($poller_id == '1' ? cacti_sizeof($polling_hosts) - 1 : cacti_sizeof($polling_hosts)), $hosts_per_process, $num_polling_items, $rrds_processed);
 
 					break;
-				} elseif (microtime(true) - $mtb < 1) {
-					sleep(1);
+				} else {
+					if (read_config_option('log_verbosity') >= POLLER_VERBOSITY_MEDIUM || $debug) {
+						print 'Waiting on ' . ($started_processes - $finished_processes) . ' of ' . $started_processes . " pollers.\n";
+					}
+
+					$mtb = microtime(true);
+
+					if ($poller_id == 1) {
+						$rrds_processed = $rrds_processed + process_poller_output($rrdtool_pipe);
+					}
+
+					// end the process if the runtime exceeds MAX_POLLER_RUNTIME
+					if (($poller_start + MAX_POLLER_RUNTIME) < time()) {
+						cacti_log('Maximum runtime of ' . MAX_POLLER_RUNTIME . ' seconds exceeded. Exiting.', true, 'POLLER');
+						admin_email(__('Cacti System Warning'), __('Maximum runtime of %d seconds exceeded for poller id %d. Exiting.', MAX_POLLER_RUNTIME, $poller_id));
+
+						// generate a snmp notification
+						snmpagent_poller_exiting();
+
+						api_plugin_hook_function('poller_exiting');
+						log_cacti_stats($loop_start, $method, $concurrent_processes, $max_threads,
+							($poller_id == '1' ? cacti_sizeof($polling_hosts) - 1 : cacti_sizeof($polling_hosts)), $hosts_per_process, $num_polling_items, $rrds_processed);
+
+						break;
+					} elseif (microtime(true) - $mtb < 1) {
+						sleep(1);
+					}
 				}
 			}
 		}
@@ -724,7 +745,7 @@ while ($poller_runs_completed < $poller_runs) {
 			}
 		}
 	} else {
-		cacti_log('NOTE: There are no items in your poller for this polling cycle!', true, 'POLLER', $level);
+		cacti_log('WARNING: The Cacti Data Collector is currently disabled!', true, 'POLLER');
 	}
 
 	$poller_runs_completed++;
@@ -778,6 +799,11 @@ while ($poller_runs_completed < $poller_runs) {
 		cacti_log('WARNING: Cacti Polling Cycle Exceeded Poller Interval by ' . ($loop_end-$loop_start-$poller_interval) . ' seconds', true, 'POLLER', $level);
 	}
 
+	if (!$logged) {
+		log_cacti_stats($loop_start, $method, $concurrent_processes, $max_threads,
+			($poller_id == '1' ? cacti_sizeof($polling_hosts) - 1 : cacti_sizeof($polling_hosts)), $hosts_per_process, $num_polling_items, $rrds_processed);
+	}
+
 	// flush the boost table if in recovery mode
 	poller_recovery_flush_boost($poller_id);
 }
@@ -848,10 +874,12 @@ function poller_replicate_check() {
 		AND (last_sync = '0000-00-00 00:00:00' OR requires_sync = 'on'
 		OR (UNIX_TIMESTAMP()-UNIX_TIMESTAMP(last_sync) >= IFNULL(sync_interval, $sync_interval)))");
 
-	foreach($pollers as $poller) {
-		$command_string = cacti_escapeshellcmd(read_config_option('path_php_binary'));
-		$extra_args = '-q ' . cacti_escapeshellarg($config['base_path'] . '/cli/poller_replicate.php') . ' --poller=' . $poller['id'];
-		exec_background($command_string, $extra_args);
+	if (cacti_sizeof($pollers)) {
+		foreach($pollers as $poller) {
+			$command_string = cacti_escapeshellcmd(read_config_option('path_php_binary'));
+			$extra_args = '-q ' . cacti_escapeshellarg($config['base_path'] . '/cli/poller_replicate.php') . ' --poller=' . $poller['id'];
+			exec_background($command_string, $extra_args);
+		}
 	}
 }
 
@@ -877,7 +905,7 @@ function poller_enabled_check($poller_id) {
 
 function log_cacti_stats($loop_start, $method, $concurrent_processes, $max_threads, $num_hosts,
 	$hosts_per_process, $num_polling_items, $rrds_processed) {
-	global $poller_id, $poller_db_cnn_id;
+	global $poller_id, $poller_db_cnn_id, $logged;
 
 	// get the poller data
 	$poller = db_fetch_row_prepared('SELECT *
@@ -909,7 +937,7 @@ function log_cacti_stats($loop_start, $method, $concurrent_processes, $max_threa
 		set_config_option('stats_poller', $cacti_stats);
 	}
 
-	if (array_key_exists('min_time', $poller)) {
+	if (is_array($poller) && array_key_exists('min_time', $poller)) {
 		// calculate min/max/average timings
 		$total_time  = $loop_end-$loop_start;
 		$total_polls = $poller['total_polls'];
@@ -947,6 +975,8 @@ function log_cacti_stats($loop_start, $method, $concurrent_processes, $max_threa
 	snmpagent_cacti_stats_update($perf_data);
 
 	api_plugin_hook_function('cacti_stats_update', $perf_data);
+
+	$logged = true;
 }
 
 function multiple_poller_boost_check() {
