@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -73,7 +73,7 @@ if (cacti_sizeof($parms)) {
 			case '--version':
 			case '-V':
 				display_version();
-				exit;
+				exit(0);
 			case '-H':
 			case '--help':
 				display_help();
@@ -117,6 +117,11 @@ if ($debug) {
 	$verbosity = POLLER_VERBOSITY_MEDIUM;
 }
 
+/* silently end if the registered process is still running, or process table missing */
+if (!register_process_start('commands', 'master', $poller_id, read_config_option('commands_timeout'))) {
+	exit(0);
+}
+
 if (cacti_sizeof($poller_commands)) {
 	foreach ($poller_commands as $command) {
 		switch ($command['action']) {
@@ -182,6 +187,8 @@ if ($recached_hosts > 0) {
 db_execute_prepared('REPLACE INTO settings (name, value) VALUES (?, ?)',
 	array('stats_recache_' . $poller_id, $recache_stats), true, $poller_db_cnn_id);
 
+unregister_process('commands', 'master', $poller_id);
+
 /*  display_version - displays version information */
 function display_version() {
 	$version = get_cacti_version();
