@@ -30,7 +30,8 @@ include_once('./lib/data_query.php');
 $tree_actions = array(
 	1 => __x('dropdown action', 'Delete'),
 	2 => __x('dropdown action', 'Publish'),
-	3 => __x('dropdown action', 'Un Publish')
+	3 => __x('dropdown action', 'Un-Publish'),
+	4 => __x('dropdown action', 'Un-Lock')
 );
 
 /* set default action */
@@ -602,6 +603,12 @@ function form_actions() {
 					last_modified=NOW(),
 					modified_by=" . $_SESSION['sess_user_id'] . '
 					WHERE ' . array_to_sql_or($selected_items, 'id'));
+			} elseif (get_nfilter_request_var('drp_action') == '4') { // un-lock
+				db_execute("UPDATE graph_tree
+					SET locked=0,
+					last_modified=NOW(),
+					modified_by=" . $_SESSION['sess_user_id'] . '
+					WHERE ' . array_to_sql_or($selected_items, 'id'));
 			}
 		}
 
@@ -660,6 +667,15 @@ function form_actions() {
 			</tr>\n";
 
 			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Un-publish Tree', 'Un-publish Trees', cacti_sizeof($tree_array)) . "'>";
+		} elseif (get_nfilter_request_var('drp_action') == '4') { // un-lock
+			print "<tr>
+				<td class='textArea' class='odd'>
+					<p>" . __n('Click \'Continue\' to un-lock the following Tree.', 'Click \'Continue\' to un-lock following Trees.', cacti_sizeof($tree_array)) . "</p>
+					<div class='itemlist'><ul>$tree_list</ul></div>
+				</td>
+			</tr>\n";
+
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Un-lock Tree', 'Un-lock Trees', cacti_sizeof($tree_array)) . "'>";
 		}
 	} else {
 		raise_message(40);
@@ -815,7 +831,7 @@ function tree_edit() {
 		html_start_box('', '100%', '', '3', 'center', '');
 		html_header($display_text);
 
-		print "<tr class='tableRow'><td style='padding:7px;'><div id='sites'>\n";
+		print "<tr class='tableRow'><td style='padding:7px;'><div id='sites' style='display:none;'>\n";
 		display_sites();
 		print "</div></td></tr>\n";
 
@@ -850,7 +866,7 @@ function tree_edit() {
 		html_start_box('', '100%', '', '3', 'center', '');
 		html_header($display_text);
 
-		print "<tr class='tableRow'><td style='padding:7px;'><div id='hosts'>\n";
+		print "<tr class='tableRow'><td style='padding:7px;'><div id='hosts' style='display:none;'>\n";
 		display_hosts();
 		print "</div></td></tr>\n";
 
@@ -884,7 +900,7 @@ function tree_edit() {
 		html_start_box('', '100%', '', '3', 'center', '');
 		html_header($display_text);
 
-		print "<tr class='tableRow'><td style='padding:7px;'><div id='graphs'>\n";
+		print "<tr class='tableRow'><td style='padding:7px;'><div id='graphs' style='display:none;'>\n";
 		display_graphs();
 		print "</div></td></tr>\n";
 
@@ -911,7 +927,7 @@ function tree_edit() {
 
 		function createNode() {
 			var ref = $('#ctree').jstree(true);
-			sel = ref.create_node('#', '<?php print __('New Node');?>', '0');
+			sel = ref.create_node('#', '<?php print __esc('New Node');?>', '0');
 			if (sel) {
 				ref.edit(sel);
 			}
@@ -1080,14 +1096,16 @@ function tree_edit() {
 
 			function resizer() {
 				if ($('#ctree').length) {
-					height  = parseInt($(window).height()-$('#ctree').offset().top-10)+'px';
-					sheight = parseInt($(window).height()-$('#sites').offset().top-10)+'px';
-					hheight = parseInt($(window).height()-$('#hosts').offset().top-10)+'px';
-					gheight = parseInt($(window).height()-$('#graphs').offset().top-10)+'px';
-					$('#ctree').css('height', height).css('overflow','auto');;
-					$('#hosts').css('height', hheight).css('overflow','auto');;
-					$('#sites').css('height', hheight).css('overflow','auto');;
-					$('#graphs').css('height', gheight).css('overflow','auto');;
+					var wheight = $(window).height();
+					var cTop    = $('#ctree').parent().offset().top;
+					var sTop    = $('#sites').parent().offset().top;
+					var height  = wheight - cTop - 10;
+					var sheight = wheight - sTop - 10;
+
+					$('#ctree').css('height', height).css('overflow','auto');
+					$('#hosts').css('height', sheight).css('overflow','auto');
+					$('#sites').css('height', sheight).css('overflow','auto');
+					$('#graphs').css('height', sheight).css('overflow','auto');
 
 					switchDisplay();
 				}
@@ -1216,7 +1234,7 @@ function tree_edit() {
 						data.instance.set_text(data.node, d.text);
 						data.instance.edit(data.node);
 
-						if (d.text != '<?php print __('New Node');?>') {
+						if (d.text != '<?php print __esc('New Node');?>') {
 							$('.jstree').jstree(true).refresh();
 						}
 					})
@@ -1251,37 +1269,18 @@ function tree_edit() {
 				oid = data.original.id;
 
 				if (oid.search('thost') >= 0) {
-					set = hostsDropSet;
-				}else if (oid.search('tsite') >= 0) {
-					set = sitesDropSet;
+					$('#hosts').jstree().deselect_all();
+				} else if (oid.search('tsite') >= 0) {
+					$('#sites').jstree().deselect_all();
 				} else {
-					set = graphsDropSet;
+					$('#graphs').jstree().deselect_all();
 				}
 
-				if (set != '' && set.selected.length > 0) {
-					entries = set.selected;
-					$.each(entries, function(i, id) {
-						$.get('?action=copy_node', { 'id' : id, 'tree_id' : $('#id').val(), 'parent' : data.parent, 'position' : data.position })
-							.always(function () {
-								var st = data.instance.get_state();
-								data.instance.load_node(data.instance.get_parent(data.node.id), function () { this.set_state(st); });
-							})
-					});
-
-					if (oid.search('thost') >= 0) {
-						$('#hosts').jstree().deselect_all();
-					} else if (oid.search('tsite') >= 0) {
-						$('#sites').jstree().deselect_all();
-					} else {
-						$('#graphs').jstree().deselect_all();
-					}
-				} else {
-					$.get('?action=copy_node', { 'id' : data.original.id, 'tree_id' : $('#id').val(), 'parent' : data.parent, 'position' : data.position })
-						.always(function () {
-							var st = data.instance.get_state();
-							data.instance.load_node(data.instance.get_parent(data.node.id), function () { this.set_state(st); });
-						});
-				}
+				$.get('?action=copy_node', { 'id' : data.original.id, 'tree_id' : $('#id').val(), 'parent' : data.parent, 'position' : data.position })
+				.always(function () {
+					var st = data.instance.get_state();
+					data.instance.load_node(data.instance.get_parent(data.node.id), function () { this.set_state(st); });
+				});
 			})<?php } else {?>.children().bind('contextmenu', function(event) {
 				return false;
 			})<?php }?>;
@@ -1331,16 +1330,6 @@ function tree_edit() {
 						$('#ctree').jstree('clear_state');
 					}
 				})<?php if ($editable) {?>
-				.on('hover_node.jstree', function(e, data) {
-					var myset = {};
-					myset.selected = [ data.node.id ];
-
-					if (data.node.id.includes('thost')) {
-						hostsDropSet = myset;
-					} else if (data.node.id.includes('tgraph')) {
-						graphsDropSet = myset;
-					}
-				})
 				.on('select_node.jstree', function(e, data) {
 					if (type == 'graphs') {
 						graphsDropSet = data;
@@ -1359,7 +1348,7 @@ function tree_edit() {
 						getGraphData();
 					}
 				})
-				.on('deselect_node.jstree', function(e,data) {
+				.on('deselect_node.jstree', function(e, data) {
 					if (type == 'graphs') {
 						graphsDropSet = data;
 					} else {
@@ -1370,6 +1359,7 @@ function tree_edit() {
 				$(element).children().bind('contextmenu', function(event) {
 					return false;
 				});
+				$(element).show();
 		}
 
 		function branchContext(nodeid) {
@@ -1379,7 +1369,7 @@ function tree_edit() {
 					'separator_after'	: true,
 					'icon'				: 'fa fa-folder',
 					'_disabled'			: false,
-					'label'				: '<?php print __('Create');?>',
+					'label'				: '<?php print __esc('Create');?>',
 					'action'			: function (data) {
 						var inst = $.jstree.reference(data.reference);
 						var obj = inst.get_node(data.reference);
@@ -1393,7 +1383,7 @@ function tree_edit() {
 					'separator_after'	: false,
 					'icon'				: 'fa fa-pencil-alt',
 					'_disabled'			: false,
-					'label'				: '<?php print __('Rename');?>',
+					'label'				: '<?php print __esc('Rename');?>',
 					'action'			: function (data) {
 						var inst = $.jstree.reference(data.reference);
 						var obj = inst.get_node(data.reference);
@@ -1405,7 +1395,7 @@ function tree_edit() {
 					'icon'				: 'fa fa-times',
 					'separator_after'	: false,
 					'_disabled'			: false,
-					'label'				: '<?php print __('Delete');?>',
+					'label'				: '<?php print __esc('Delete');?>',
 					'action'			: function (data) {
 						var inst = $.jstree.reference(data.reference);
 						var obj = inst.get_node(data.reference);
@@ -1420,14 +1410,14 @@ function tree_edit() {
 					'separator_before'	: true,
 					'icon'				: 'fa fa-sort',
 					'separator_after'	: false,
-					'label'				: '<?php print __('Branch Sorting');?>',
+					'label'				: '<?php print __esc('Branch Sorting');?>',
 					'action'			: false,
 					'submenu' : {
 						'inherit' : {
 							'separator_before'	: false,
 							'separator_after'	: false,
 							'icon'				: getBranchSortIcon('inherit', nodeid),
-							'label'				: '<?php print __('Inherit');?>',
+							'label'				: '<?php print __esc('Inherit');?>',
 							'action'			: function (data) {
 								setBranchSortOrder('inherit', nodeid);
 								var inst = $.jstree.reference(data.reference);
@@ -1441,7 +1431,7 @@ function tree_edit() {
 							'separator_before'	: false,
 							'separator_after'	: false,
 							'icon'				: getBranchSortIcon('manual', nodeid),
-							'label'				: '<?php print __('Manual');?>',
+							'label'				: '<?php print __esc('Manual');?>',
 							'action'			: function (data) {
 								setBranchSortOrder('manual', nodeid);
 								var inst = $.jstree.reference(data.reference);
@@ -1455,7 +1445,7 @@ function tree_edit() {
 							'separator_before'	: false,
 							'icon'				: getBranchSortIcon('alpha', nodeid),
 							'separator_after'	: false,
-							'label'				: '<?php print __('Alphabetic');?>',
+							'label'				: '<?php print __esc('Alphabetic');?>',
 							'action'			: function (data) {
 								setBranchSortOrder('alpha', nodeid);
 								var inst = $.jstree.reference(data.reference);
@@ -1469,7 +1459,7 @@ function tree_edit() {
 							'separator_before'	: false,
 							'icon'				: getBranchSortIcon('natural', nodeid),
 							'separator_after'	: false,
-							'label'				: '<?php print __('Natural');?>',
+							'label'				: '<?php print __esc('Natural');?>',
 							'action'			: function (data) {
 								setBranchSortOrder('natural', nodeid);
 								var inst = $.jstree.reference(data.reference);
@@ -1483,7 +1473,7 @@ function tree_edit() {
 							'separator_before'	: false,
 							'icon'				: getBranchSortIcon('numeric', nodeid),
 							'separator_after'	: false,
-							'label'				: '<?php print __('Numeric');?>',
+							'label'				: '<?php print __esc('Numeric');?>',
 							'action'			: function (data) {
 								setBranchSortOrder('numeric', nodeid);
 								var inst = $.jstree.reference(data.reference);
@@ -1499,14 +1489,14 @@ function tree_edit() {
 					'separator_before'	: true,
 					'icon'				: 'fa fa-edit',
 					'separator_after'	: false,
-					'label'				: '<?php print __('Edit');?>',
+					'label'				: '<?php print __esc('Edit');?>',
 					'action'			: false,
 					'submenu' : {
 						'cut' : {
 							'separator_before'	: false,
 							'separator_after'	: false,
 							'icon'				: 'fa fa-cut',
-							'label'				: '<?php print __('Cut');?>',
+							'label'				: '<?php print __esc('Cut');?>',
 							'action'			: function (data) {
 								var inst = $.jstree.reference(data.reference);
 								var obj = inst.get_node(data.reference);
@@ -1521,7 +1511,7 @@ function tree_edit() {
 							'separator_before'	: false,
 							'icon'				: 'fa fa-copy',
 							'separator_after'	: false,
-							'label'				: '<?php print __('Copy');?>',
+							'label'				: '<?php print __esc('Copy');?>',
 							'action'			: function (data) {
 								var inst = $.jstree.reference(data.reference);
 								var obj = inst.get_node(data.reference);
@@ -1539,7 +1529,7 @@ function tree_edit() {
 								return !$.jstree.reference(data.reference).can_paste();
 							},
 							'separator_after'	: false,
-							'label'				: '<?php print __('Paste');?>',
+							'label'				: '<?php print __esc('Paste');?>',
 							'action'			: function (data) {
 								var inst = $.jstree.reference(data.reference);
 								var obj = inst.get_node(data.reference);
@@ -1558,7 +1548,7 @@ function tree_edit() {
 					'icon'				: 'fa fa-times',
 					'separator_after'	: false,
 					'_disabled'			: false, //(this.check('delete_node', data.reference, this.get_parent(data.reference), '')),
-					'label'				: '<?php print __('Delete');?>',
+					'label'				: '<?php print __esc('Delete');?>',
 					'action'			: function (data) {
 						var inst = $.jstree.reference(data.reference);
 						var obj = inst.get_node(data.reference);
@@ -1573,14 +1563,14 @@ function tree_edit() {
 					'separator_before'	: true,
 					'icon'				: 'fa fa-edit',
 					'separator_after'	: false,
-					'label'				: '<?php print __('Edit');?>',
+					'label'				: '<?php print __esc('Edit');?>',
 					'action'			: false,
 					'submenu' : {
 						'cut' : {
 							'separator_before'	: false,
 							'separator_after'	: false,
 							'icon'				: 'fa fa-cut',
-							'label'				: '<?php print __('Cut');?>',
+							'label'				: '<?php print __esc('Cut');?>',
 							'action'			: function (data) {
 								var inst = $.jstree.reference(data.reference);
 								var obj = inst.get_node(data.reference);
@@ -1595,7 +1585,7 @@ function tree_edit() {
 							'separator_before'	: false,
 							'icon'				: 'fa fa-copy',
 							'separator_after'	: false,
-							'label'				: '<?php print __('Copy');?>',
+							'label'				: '<?php print __esc('Copy');?>',
 							'action'			: function (data) {
 								var inst = $.jstree.reference(data.reference);
 								var obj = inst.get_node(data.reference);
@@ -1618,7 +1608,7 @@ function tree_edit() {
 					'icon'				: 'fa fa-times',
 					'separator_after'	: false,
 					'_disabled'			: false,
-					'label'				: '<?php print __('Delete');?>',
+					'label'				: '<?php print __esc('Delete');?>',
 					'action'			: function (data) {
 						var inst = $.jstree.reference(data.reference);
 						var obj = inst.get_node(data.reference);
@@ -1639,7 +1629,7 @@ function tree_edit() {
 					'icon'				: 'fa fa-times',
 					'separator_after'	: false,
 					'_disabled'			: false,
-					'label'				: '<?php print __('Delete');?>',
+					'label'				: '<?php print __esc('Delete');?>',
 					'action'			: function (data) {
 						var inst = $.jstree.reference(data.reference);
 						var obj = inst.get_node(data.reference);
@@ -1654,14 +1644,14 @@ function tree_edit() {
 					'separator_before'	: true,
 					'separator_after'	: false,
 					'icon'				: 'fa fa-sort',
-					'label'				: '<?php print __('Sorting Type');?>',
+					'label'				: '<?php print __esc('Sorting Type');?>',
 					'action'			: false,
 					'submenu' : {
 						'hsgt' : {
 							'separator_before'	: false,
 							'icon'				: getHostSortIcon('hsgt', nodeid),
 							'separator_after'	: false,
-							'label'				: '<?php print __('Graph Template');?>',
+							'label'				: '<?php print __esc('Graph Template');?>',
 							'action'			: function (data) {
 								setHostSortOrder('hsgt', nodeid);
 							}
@@ -1670,7 +1660,7 @@ function tree_edit() {
 							'separator_before'	: false,
 							'icon'				: getHostSortIcon('hsdq', nodeid),
 							'separator_after'	: false,
-							'label'				: '<?php print __('Data Query Index');?>',
+							'label'				: '<?php print __esc('Data Query Index');?>',
 							'action'			: function (data) {
 								setHostSortOrder('hsdq', nodeid);
 							}
@@ -1681,14 +1671,14 @@ function tree_edit() {
 					'separator_before'	: true,
 					'icon'				: 'fa fa-edit',
 					'separator_after'	: false,
-					'label'				: '<?php print __('Edit');?>',
+					'label'				: '<?php print __esc('Edit');?>',
 					'action'			: false,
 					'submenu' : {
 						'cut' : {
 							'separator_before'	: false,
 							'separator_after'	: false,
 							'icon'				: 'fa fa-cut',
-							'label'				: '<?php print __('Cut');?>',
+							'label'				: '<?php print __esc('Cut');?>',
 							'action'			: function (data) {
 								var inst = $.jstree.reference(data.reference),
 									obj = inst.get_node(data.reference);
@@ -1703,7 +1693,7 @@ function tree_edit() {
 							'separator_before'	: false,
 							'icon'				: 'fa fa-copy',
 							'separator_after'	: false,
-							'label'				: '<?php print __('Copy');?>',
+							'label'				: '<?php print __esc('Copy');?>',
 							'action'			: function (data) {
 								var inst = $.jstree.reference(data.reference),
 									obj = inst.get_node(data.reference);
@@ -1753,7 +1743,7 @@ function display_sites() {
 
 	if (cacti_sizeof($sites)) {
 		foreach($sites as $s) {
-			print "<ul><li id='tsite:" . $s['id'] . "' data-jstree='{ \"type\" : \"site\"}'>" . $s['name'] . "</li></ul>\n";
+			print "<ul><li id='tsite:" . $s['id'] . "' data-jstree='{ \"type\" : \"site\"}'>" . html_escape($s['name']) . "</li></ul>\n";
 		}
 	}
 }
@@ -1770,11 +1760,11 @@ function display_hosts() {
 		$sql_where .= ($sql_where != '' ? ' AND ':'') . 'h.site_id = ' . get_filter_request_var('site_id');
 	}
 
-	$hosts = get_allowed_devices($sql_where, 'description', '20');
+	$hosts = get_allowed_devices($sql_where, 'description', read_config_option('autocomplete_rows'));
 
 	if (cacti_sizeof($hosts)) {
 		foreach($hosts as $h) {
-			print "<ul><li id='thost:" . $h['id'] . "' data-jstree='{ \"type\" : \"device\"}'>" . $h['description'] . ' (' . $h['hostname'] . ')' . "</li></ul>\n";
+			print "<ul><li id='thost:" . $h['id'] . "' data-jstree='{ \"type\" : \"device\"}'>" . html_escape($h['description']) . ' (' . html_escape($h['hostname']) . ')' . "</li></ul>\n";
 		}
 	}
 }
@@ -1812,7 +1802,7 @@ function display_graphs() {
 		ON gl.host_id = h.id
 		$sql_where
 		ORDER BY title_cache
-		LIMIT 20");
+		LIMIT " . read_config_option('autocomplete_rows'));
 
 	if (cacti_sizeof($graphs)) {
 		foreach($graphs as $g) {
@@ -2006,18 +1996,79 @@ function tree() {
 	html_start_box('', '100%', '', '3', 'center', '');
 
 	$display_text = array(
-		'name' => array('display' => __('Tree Name'), 'align' => 'left', 'sort' => 'ASC', 'tip' => __('The name by which this Tree will be referred to as.')),
-		'id' => array('display' => __('ID'), 'align' => 'right', 'sort' => 'ASC', 'tip' => __('The internal database ID for this Tree.  Useful when performing automation or debugging.')),
-		'enabled' => array('display' => __('Published'), 'align' => 'left', 'sort' => 'ASC', 'tip' => __('Unpublished Trees cannot be viewed from the Graph tab')),
-		'locked' => array('display' => __('Locked'), 'align' => 'left', 'sort' => 'ASC', 'tip' => __('A Tree must be locked in order to be edited.')),
-		'user_id' => array('display' => __('Owner'), 'align' => 'left', 'sort' => 'ASC', 'tip' => __('The original author of this Tree.')),
-		'sequence' => array('display' => __('Order'), 'align' => 'center', 'sort' => 'ASC', 'tip' => __('To change the order of the trees, first sort by this column, press the up or down arrows once they appear.')),
-		'last_modified' => array('display' => __('Last Edited'), 'align' => 'right', 'sort' => 'ASC', 'tip' => __('The date that this Tree was last edited.')),
-		'modified_by' => array('display' => __('Edited By'), 'align' => 'right', 'sort' => 'ASC', 'tip' => __('The last user to have modified this Tree.')),
-		'sites' => array('display' => __('Sites'), 'align' => 'right', 'sort' => 'DESC', 'tip' => __('The total number of Site Branches in this Tree.')),
-		'branches' => array('display' => __('Branches'), 'align' => 'right', 'sort' => 'DESC', 'tip' => __('The total number of Branches in this Tree.')),
-		'hosts' => array('display' => __('Devices'), 'align' => 'right', 'sort' => 'DESC', 'tip' => __('The total number of individual Devices in this Tree.')),
-		'graphs' => array('display' => __('Graphs'), 'align' => 'right', 'sort' => 'DESC', 'tip' => __('The total number of individual Graphs in this Tree.')));
+		'name' => array(
+			'display' => __('Tree Name'),
+			'align' => 'left',
+			'sort' => 'ASC',
+			'tip' => __('The name by which this Tree will be referred to as.')
+		),
+		'id' => array(
+			'display' => __('ID'),
+			'align' => 'right',
+			'sort' => 'ASC',
+			'tip' => __('The internal database ID for this Tree.  Useful when performing automation or debugging.')
+		),
+		'enabled' => array(
+			'display' => __('Published'),
+			'align' => 'left',
+			'sort' => 'ASC',
+			'tip' => __('Unpublished Trees cannot be viewed from the Graph tab')
+		),
+		'locked' => array(
+			'display' => __('Locked'),
+			'align' => 'left',
+			'sort' => 'ASC',
+			'tip' => __('A Tree must be locked in order to be edited.')
+		),
+		'user_id' => array(
+			'display' => __('Owner'),
+			'align' => 'left',
+			'sort' => 'ASC',
+			'tip' => __('The original author of this Tree.')
+		),
+		'sequence' => array(
+			'display' => __('Order'),
+			'align' => 'center',
+			'sort' => 'ASC',
+			'tip' => __('To change the order of the trees, first sort by this column, press the up or down arrows once they appear.')
+		),
+		'last_modified' => array(
+			'display' => __('Last Edited'),
+			'align' => 'right',
+			'sort' => 'ASC',
+			'tip' => __('The date that this Tree was last edited.')
+		),
+		'modified_by' => array(
+			'display' => __('Edited By'),
+			'align' => 'right',
+			'sort' => 'ASC',
+			'tip' => __('The last user to have modified this Tree.')
+		),
+		'sites' => array(
+			'display' => __('Sites'),
+			'align' => 'right',
+			'sort' => 'DESC',
+			'tip' => __('The total number of Site Branches in this Tree.')
+		),
+		'branches' => array(
+			'display' => __('Branches'),
+			'align' => 'right',
+			'sort' => 'DESC',
+			'tip' => __('The total number of Branches in this Tree.')
+		),
+		'hosts' => array(
+			'display' => __('Devices'),
+			'align' => 'right',
+			'sort' => 'DESC',
+			'tip' => __('The total number of individual Devices in this Tree.')
+		),
+		'graphs' => array(
+			'display' => __('Graphs'),
+			'align' => 'right',
+			'sort' => 'DESC',
+			'tip' => __('The total number of individual Graphs in this Tree.')
+		)
+	);
 
 	html_header_sort_checkbox($display_text, get_request_var('sort_column'), get_request_var('sort_direction'), false);
 
